@@ -62,15 +62,15 @@ else
 fi
 
 #Select right config.php versions:
-mv -v $dst/$wwwdirselect/tts/$TTSENGINE/config${lttsver}.php $dst/$wwwdirselect/tts/$TTSENGINE/config.php
-rm -rf $dst/$wwwdirselect/tts/$TTSENGINE/config?.php
-
+install -m $perm_files $src/www/*
+mv -v $src/www/config${lttsver}.php $src/www/config.php
+rm -rf $src/www/config?.php
 
 
 #part2
 echo "Installing Web script..."
 wwwdirselect=/var/www
-echo $n "Enter apache web root directory[$wwwdirselect]: $c"
+echo -n "Enter apache web root directory[$wwwdirselect]: "
 read wwwdiruser
 if [ -n "$wwwdiruser" ]; then
 	wwwdirselect=$wwwdiruser
